function [fitness,variance] = calculate_fitness(foldername,target)
%% Import
input = [];
output = [];
for i = 1:50
    load(strcat(foldername,'\training_set_',num2str(i)));
    input = [input;data.dx data.dy data.dYaw];
    output = [output;data.t data.A1 data.phi1 data.phi2];
end

fprintf('The mean is %0.2f cm in x, %0.2f cm in y and %0.2f in theta.\n',...
    mean(input(:,1))*100,mean(input(:,2))*100,mean(input(:,3))/pi*180)

%% Calculate fitness
fitness = 0;
decayFactor = 25;
for i = 1:length(input)
    fitness = fitness + exp(-decayFactor*norm(input(i,1:2)-target));
end

% Variances
varx = var(input(:,1));
vary = var(input(:,2));

% Error propagation
variance = 0;
for i = 1:length(input)
    root = norm(target-input(i,1:2));
    varVec = decayFactor*(target-input(i,1:2))*exp(-decayFactor*root)/root;
    variance = variance + (varVec(1)^2)*varx+(varVec(2)^2)*vary;
end

%% Plot
figure
x = input(:,1)*100;
y = input(:,2)*100;
u = -sin(input(:,3));
v = cos(input(:,3));
hold on
quiver(x,y,u,v,2)
plot(0,10,'rx','MarkerSize',10,'LineWidth',2)
plot(mean(x),mean(y),'o')
hold off
axis([-20 20 -20 20])
axis('square')
grid on
xlabel('dx [cm]')
ylabel('dy [cm]')
legend('Data','Target','Mean')
